@@ -3,7 +3,7 @@
 #                                BITSMITHS                                     #
 #                           https://bitsmiths.co.za                            #
 # **************************************************************************** #
-#  Copyright (C) 2015 - 2021 Bitsmiths (Pty) Ltd.  All rights reserved.        #
+#  Copyright (C) 2015 - 2022 Bitsmiths (Pty) Ltd.  All rights reserved.        #
 #   * https://bitbucket.org/bitsmiths_za/bitsmiths                             #
 #                                                                              #
 #  Permission is hereby granted, free of charge, to any person obtaining a     #
@@ -113,8 +113,6 @@ class AuditAsync(BaseAudit, TransactionableAsync):
             if len(diffs) < 1:
                 continue
 
-            tobj = self._cfg.get(dobj['name'])
-
             kdata = dobj.get('adict')
 
             if kdata is None:
@@ -124,9 +122,7 @@ class AuditAsync(BaseAudit, TransactionableAsync):
                 tran.rec.id,
                 dobj['dtype'],
                 dobj['name'],
-                dobj['pk'],
-                tobj['par'],
-                self._get_key(dobj['name'], 'Foreign', tobj['pcols'], kdata))
+                dobj['pk'])
 
             if dobj['name'] not in tbls:
                 tbls.append(dobj['name'])
@@ -196,8 +192,6 @@ class AuditAsync(BaseAudit, TransactionableAsync):
             'id'    : tcfg.rec.id,
             'pk'    : tcfg.rec.col_pk.split('|'),
             'ign'   : tcfg.rec.col_ignr.split('|'),
-            'par'   : tcfg.rec.par_id,
-            'pcols' : tcfg.rec.par_col.split('|'),
         }
 
         self._cfg[tcfg.rec.id] = tobj
